@@ -26,12 +26,15 @@ import org.eclipse.jgit.transport.CredentialsProvider;
 import org.eclipse.jgit.transport.UsernamePasswordCredentialsProvider;
 import org.junit.Ignore;
 import org.junit.Test;
+import org.kie.soup.commons.util.Maps;
 import org.uberfire.java.nio.file.FileStore;
 import org.uberfire.java.nio.file.Path;
 import org.uberfire.java.nio.fs.jgit.util.Git;
 import org.uberfire.java.nio.fs.jgit.util.GitImpl;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -56,6 +59,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.isReadOnly()).isFalse();
@@ -82,6 +86,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.isReadOnly()).isFalse();
@@ -113,6 +118,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.getName()).isEqualTo("my-repo");
@@ -134,6 +140,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.isReadOnly()).isFalse();
@@ -159,6 +166,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.isReadOnly()).isFalse();
@@ -183,6 +191,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("/path/to/some/place.txt");
@@ -212,6 +221,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("path/to/some/place.txt");
@@ -241,6 +251,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("test-branch",
@@ -271,6 +282,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("test-branch",
@@ -301,6 +313,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("test-branch",
@@ -332,6 +345,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         final Path path = fileSystem.getPath("test-branch",
@@ -362,6 +376,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         assertThat(fileSystem.getFileStores()).hasSize(1);
@@ -384,6 +399,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                       createFSLock(git1),
                                                                       "my-repo1",
                                                                       CredentialsProvider.getDefault(),
+                                                                      null,
                                                                       null);
 
         final Git git2 = setupGit();
@@ -394,6 +410,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                       createFSLock(git2),
                                                                       "my-repo2",
                                                                       CredentialsProvider.getDefault(),
+                                                                      null,
                                                                       null);
 
         final Path path1 = fileSystem1.getPath("master",
@@ -419,6 +436,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
         fileSystem.newWatchService();
     }
@@ -435,6 +453,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
         fileSystem.getUserPrincipalLookupService();
     }
@@ -451,6 +470,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
         fileSystem.getPathMatcher("*");
     }
@@ -467,6 +487,7 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
                                                                      createFSLock(git),
                                                                      "my-repo",
                                                                      CredentialsProvider.getDefault(),
+                                                                     null,
                                                                      null);
 
         fileSystem.lock();
@@ -498,4 +519,33 @@ public class JGitFileSystemImplTest extends AbstractTestInfra {
         verify(lockSpy,
                times(1)).physicalUnLockOnFS();
     }
+
+    @Test
+    public void testSetPublicURI() throws IOException, GitAPIException {
+
+        final JGitFileSystemProvider fsProvider = mock(JGitFileSystemProvider.class);
+
+        final Git git = setupGit();
+
+        final JGitFileSystemImpl fileSystem = new JGitFileSystemImpl(fsProvider,
+                                                                     new Maps.Builder<String, String>()
+                                                                             .put("ssh", "localhost:8080/git")
+                                                                             .build(),
+                                                                     git,
+                                                                     createFSLock(git),
+                                                                     "my-repo",
+                                                                     CredentialsProvider.getDefault(),
+                                                                     null,
+                                                                     null);
+
+        assertTrue(checkProtocolPresent(fileSystem.toString(), "ssh"));
+        assertFalse(checkProtocolPresent(fileSystem.toString(), "http"));
+
+        fileSystem.setPublicURI(new Maps.Builder<String, String>()
+                                        .put("http", "localhost:8080/git")
+                                        .put("ssh", "localhost:8080/git")
+                                        .build());
+        assertTrue(checkProtocolPresent(fileSystem.toString(), "ssh"));
+        assertTrue(checkProtocolPresent(fileSystem.toString(), "http"));
+    }
 }
